@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from .utils import input_or_output, get_dataset_property
+from .utils import input_or_output, get_asset_property
 
 
 class Dataset(ABC):
@@ -33,4 +33,4 @@ class Dataset(ABC):
         pass
 
     def get_storage_type(self):
-        return get_dataset_property(name=self.name, prop="dataStorageType")
+        return get_asset_property(asset_name=self.name, property="storage_type")
